@@ -1,3 +1,5 @@
+# Copyright (c) Microsoft Corporation. All rights reserved.
+# Licensed under the MIT License.
 """Python functions loader."""
 
 
@@ -12,6 +14,7 @@ import typing
 
 from .constants import MODULE_NOT_FOUND_TS_URL
 from .utils.wrappers import attach_message_to_exception
+from os import PathLike, fspath
 
 
 _AZURE_NAMESPACE = '__app__'
@@ -19,11 +22,11 @@ _AZURE_NAMESPACE = '__app__'
 _submodule_dirs = []
 
 
-def register_function_dir(path: os.PathLike):
-    _submodule_dirs.append(os.fspath(path))
+def register_function_dir(path: PathLike) -> None:
+    _submodule_dirs.append(fspath(path))
 
 
-def install():
+def install() -> None:
     if _AZURE_NAMESPACE not in sys.modules:
         # Create and register the __app__ namespace package.
         ns_spec = importlib.machinery.ModuleSpec(_AZURE_NAMESPACE, None)
@@ -32,7 +35,7 @@ def install():
         sys.modules[_AZURE_NAMESPACE] = ns_pkg
 
 
-def uninstall():
+def uninstall() -> None:
     pass
 
 
